@@ -12,35 +12,27 @@ setMethod("TotalVarDist", signature(e1 = "AbscontDistribution",
         lower <- min(lower1, lower2)
         upper <- max(upper1, upper2)
 
-        integrand <- function(x, e1, e2){ 0.5*abs(d(e1)(x)-d(e2)(x)) }
-        res <- distrExIntegrate(integrand, lower = lower, upper = upper, e1 = e1, e2 = e2, 
-                        rel.tol=.Machine$double.eps^0.3)
-        names(res) <- "total variation distance"
+        integrand <- function(x, dfun1, dfun2){ 0.5*abs(dfun1(x)-dfun2(x)) }
+        res <- distrExIntegrate(integrand, lower = lower, upper = upper, 
+                    dfun1 = d(e1), dfun2 = d(e2), rel.tol=.Machine$double.eps^0.3)
 
-        return(res)
+        return(list(e1 = e1, e2 = e2, total.variation.distance = res))
     })
 setMethod("TotalVarDist", signature(e1 = "DiscreteDistribution",
                                     e2 = "DiscreteDistribution"),
     function(e1, e2){
         supp <- union(support(e1), support(e2))
         res <- 0.5*sum(abs(d(e1)(supp)-d(e2)(supp)))
-        names(res) <- "total variation distance"
 
-        return(res)
+        return(list(e1 = e1, e2 = e2, total.variation.distance = res))
     })
 setMethod("TotalVarDist", signature(e1 = "DiscreteDistribution",
                                     e2 = "AbscontDistribution"),
     function(e1, e2){ 
-        res <- 1
-        names(res) <- "total variation distance"
-
-        return(res) 
+        return(list(e1 = e1, e2 = e2, total.variation.distance = 1))
     })
 setMethod("TotalVarDist", signature(e1 = "AbscontDistribution",
                                     e2 = "DiscreteDistribution"),
     function(e1, e2){ 
-        res <- 1
-        names(res) <- "total variation distance"
-
-        return(res) 
+        return(list(e1 = e1, e2 = e2, total.variation.distance = 1))
     })
